==> jc-1.4.0.tar.gz: soot/grimp/internal/GNegExpr.h <==
// public class soot.grimp.internal.GNegExpr

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 46efa4c957171bde soot_grimp_internal_GNegExpr
// @dep_class f5a35044f0376f2e soot_jimple_internal_AbstractNegExpr
// @dep_class 2880d6831146619b soot_jimple_internal_AbstractUnopExpr

// header file dependencies
// @dep_header soot_jimple_internal_AbstractNegExpr

#include "soot/jimple/internal/AbstractNegExpr.h"

#ifndef _JC_soot_grimp_internal_GNegExpr_H_
#define _JC_soot_grimp_internal_GNegExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_soot_Value$object;

// Typedefs
typedef struct _jc_soot_grimp_internal_GNegExpr$sub_refs	_jc_soot_grimp_internal_GNegExpr$sub_refs;
typedef struct _jc_soot_grimp_internal_GNegExpr$sub_nonrefs	_jc_soot_grimp_internal_GNegExpr$sub_nonrefs;
typedef struct _jc_soot_grimp_internal_GNegExpr$refs	_jc_soot_grimp_internal_GNegExpr$refs;
typedef struct _jc_soot_grimp_internal_GNegExpr$nonrefs	_jc_soot_grimp_internal_GNegExpr$nonrefs;
typedef struct _jc_soot_grimp_internal_GNegExpr$object	_jc_soot_grimp_internal_GNegExpr$object;

typedef const struct _jc_soot_grimp_internal_GNegExpr$vmethods	_jc_soot_grimp_internal_GNegExpr$vmethods;
typedef const struct _jc_soot_grimp_internal_GNegExpr$vtable	_jc_soot_grimp_internal_GNegExpr$vtable;
typedef const struct _jc_soot_grimp_internal_GNegExpr$vtype	_jc_soot_grimp_internal_GNegExpr$vtype;

// Constructors
extern void _jc_soot_grimp_internal_GNegExpr$method$_init$b01f06481db4410b(_jc_env *, struct _jc_soot_grimp_internal_GNegExpr$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_grimp_internal_GNegExpr$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_grimp_internal_GNegExpr$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_grimp_internal_GNegExpr$method_info$clone$b75f2713d6705f70;

// Virtual methods structure
struct _jc_soot_grimp_internal_GNegExpr$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_grimp_internal_GNegExpr$object *);
};

// Vtable
struct _jc_soot_grimp_internal_GNegExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractUnopExpr$vmethods	soot_jimple_internal_AbstractUnopExpr;
	_jc_soot_jimple_internal_AbstractNegExpr$vmethods	soot_jimple_internal_AbstractNegExpr;
	_jc_soot_grimp_internal_GNegExpr$vmethods	soot_grimp_internal_GNegExpr;
};

// Vtype
struct _jc_soot_grimp_internal_GNegExpr$vtype {
	_jc_type			type;
	_jc_soot_grimp_internal_GNegExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_grimp_internal_GNegExpr$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_grimp_internal_GNegExpr$refs {
    _jc_soot_grimp_internal_GNegExpr$sub_refs	soot_grimp_internal_GNegExpr;
    _jc_soot_jimple_internal_AbstractNegExpr$sub_refs	soot_jimple_internal_AbstractNegExpr;
    _jc_soot_jimple_internal_AbstractUnopExpr$sub_refs	soot_jimple_internal_AbstractUnopExpr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_grimp_internal_GNegExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_grimp_internal_GNegExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractUnopExpr$sub_nonrefs	soot_jimple_internal_AbstractUnopExpr;
    _jc_soot_jimple_internal_AbstractNegExpr$sub_nonrefs	soot_jimple_internal_AbstractNegExpr;
    _jc_soot_grimp_internal_GNegExpr$sub_nonrefs	soot_grimp_internal_GNegExpr;
};

// Object instance structure
struct _jc_soot_grimp_internal_GNegExpr$object {
	_jc_soot_grimp_internal_GNegExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_grimp_internal_GNegExpr$vtype	*vtype;
	_jc_soot_grimp_internal_GNegExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_grimp_internal_GNegExpr$vtype _jc_soot_grimp_internal_GNegExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_grimp_internal_GNegExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_grimp_internal_GNegExpr$class_object;

#endif	/* _JC_soot_grimp_internal_GNegExpr_H_ */

==> jc-1.4.6.tar.gz: soot/grimp/internal/GNegExpr.h <==
// public class soot.grimp.internal.GNegExpr

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 46efa4c957171bde soot_grimp_internal_GNegExpr
// @dep_class f5a35044f0376f2e soot_jimple_internal_AbstractNegExpr
// @dep_class 2880d6831146619b soot_jimple_internal_AbstractUnopExpr

// header file dependencies
// @dep_header soot_jimple_internal_AbstractNegExpr

#include "soot/jimple/internal/AbstractNegExpr.h"

#ifndef _JC_soot_grimp_internal_GNegExpr_H_
#define _JC_soot_grimp_internal_GNegExpr_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_soot_Value$object;

// Typedefs
typedef struct _jc_soot_grimp_internal_GNegExpr$sub_refs	_jc_soot_grimp_internal_GNegExpr$sub_refs;
typedef struct _jc_soot_grimp_internal_GNegExpr$sub_nonrefs	_jc_soot_grimp_internal_GNegExpr$sub_nonrefs;
typedef struct _jc_soot_grimp_internal_GNegExpr$refs	_jc_soot_grimp_internal_GNegExpr$refs;
typedef struct _jc_soot_grimp_internal_GNegExpr$nonrefs	_jc_soot_grimp_internal_GNegExpr$nonrefs;
typedef struct _jc_soot_grimp_internal_GNegExpr$object	_jc_soot_grimp_internal_GNegExpr$object;

typedef const struct _jc_soot_grimp_internal_GNegExpr$vmethods	_jc_soot_grimp_internal_GNegExpr$vmethods;
typedef const struct _jc_soot_grimp_internal_GNegExpr$vtable	_jc_soot_grimp_internal_GNegExpr$vtable;
typedef const struct _jc_soot_grimp_internal_GNegExpr$vtype	_jc_soot_grimp_internal_GNegExpr$vtype;

// Constructors
extern void _jc_soot_grimp_internal_GNegExpr$method$_init$b01f06481db4410b(_jc_env *, struct _jc_soot_grimp_internal_GNegExpr$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_grimp_internal_GNegExpr$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_grimp_internal_GNegExpr$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_grimp_internal_GNegExpr$method_info$clone$b75f2713d6705f70;

// Virtual methods structure
struct _jc_soot_grimp_internal_GNegExpr$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_grimp_internal_GNegExpr$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_grimp_internal_GNegExpr$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_internal_AbstractUnopExpr$vmethods	soot_jimple_internal_AbstractUnopExpr;
	_jc_soot_jimple_internal_AbstractNegExpr$vmethods	soot_jimple_internal_AbstractNegExpr;
	_jc_soot_grimp_internal_GNegExpr$vmethods	soot_grimp_internal_GNegExpr;
};

// Vtype
struct _jc_soot_grimp_internal_GNegExpr$vtype {
	_jc_type			type;
	_jc_soot_grimp_internal_GNegExpr$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_grimp_internal_GNegExpr$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_grimp_internal_GNegExpr$refs {
    _jc_soot_grimp_internal_GNegExpr$sub_refs	soot_grimp_internal_GNegExpr;
    _jc_soot_jimple_internal_AbstractNegExpr$sub_refs	soot_jimple_internal_AbstractNegExpr;
    _jc_soot_jimple_internal_AbstractUnopExpr$sub_refs	soot_jimple_internal_AbstractUnopExpr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_grimp_internal_GNegExpr$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_grimp_internal_GNegExpr$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_internal_AbstractUnopExpr$sub_nonrefs	soot_jimple_internal_AbstractUnopExpr;
    _jc_soot_jimple_internal_AbstractNegExpr$sub_nonrefs	soot_jimple_internal_AbstractNegExpr;
    _jc_soot_grimp_internal_GNegExpr$sub_nonrefs	soot_grimp_internal_GNegExpr;
};

// Object instance structure
struct _jc_soot_grimp_internal_GNegExpr$object {
	_jc_soot_grimp_internal_GNegExpr$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_grimp_internal_GNegExpr$vtype	*vtype;
	_jc_soot_grimp_internal_GNegExpr$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_grimp_internal_GNegExpr$vtype _jc_soot_grimp_internal_GNegExpr$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_grimp_internal_GNegExpr, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_grimp_internal_GNegExpr$class_object;

#endif	/* _JC_soot_grimp_internal_GNegExpr_H_ */
